# Function Annotations

For programming in general, function parameters drive a function's
dynamic behavior; a function's output depends normally on its inputs.
With `uplink`, function arguments parametrize an HTTP request, and you
indicate the dynamic parts of the request by appropriately annotating
those arguments with the classes detailed in this section.

::: uplink.Path
    options:
        show_bases: false
        members: false
        inherited_members: false

::: uplink.Query
    options:
        show_bases: false
        members: false
        inherited_members: false

::: uplink.QueryMap
    options:
        show_bases: false
        members: false
        inherited_members: false

::: uplink.Header
    options:
        show_bases: false
        members: false
        inherited_members: false

::: uplink.HeaderMap
    options:
        show_bases: false
        members: false
        inherited_members: false

::: uplink.Field
    options:
        show_bases: false
        members: false
        inherited_members: false

::: uplink.FieldMap
    options:
        show_bases: false
        members: false
        inherited_members: false

::: uplink.Part
    options:
        show_bases: false
        members: false
        inherited_members: false

::: uplink.PartMap
    options:
        show_bases: false
        members: false
        inherited_members: false

::: uplink.Body
    options:
        show_bases: false
        members: false
        inherited_members: false

::: uplink.Url
    options:
        show_bases: false
        members: false
        inherited_members: false

::: uplink.Timeout
    options:
        show_bases: false
        members: false
        inherited_members: false

::: uplink.Context
    options:
        show_bases: false
        members: false
        inherited_members: false
